import {Component, inject, OnInit} from '@angular/core';
import {Observable} from "rxjs";
import {Qualification} from "../Qualification";
import {AsyncPipe} from "@angular/common";
import {
  MatCell, MatCellDef,
  MatColumnDef,
  MatHeaderCell,
  MatHeaderCellDef,
  MatHeaderRow, MatHeaderRowDef,
  MatRow, MatRowDef,
  MatTable
} from "@angular/material/table";
import QualificationService from "../../services/qualification.service";
import {MatDialog} from "@angular/material/dialog";
import {CreateComponent} from "../create/create.component";
import {MatIcon} from "@angular/material/icon";
import {MatButton, MatIconButton} from "@angular/material/button";
import {EditComponent} from "../edit/edit.component";

@Component({
  selector: 'app-qualifications',
  imports: [
    AsyncPipe,
    MatTable,
    MatHeaderCell,
    MatColumnDef,
    MatCell,
    MatHeaderRow,
    MatRow,
    MatHeaderCellDef,
    MatCellDef,
    MatHeaderRowDef,
    MatRowDef,
    MatIcon,
    MatIconButton,
    MatButton
  ],
  templateUrl: './table.component.html',
  styleUrl: './table.component.css'
})
export class QualificationsComponent implements OnInit{
  public qualifications$!: Observable<Qualification[]>;
  public readonly displayedColumns: string[] = ['id', 'skill', 'actions'];

  private readonly dialog: MatDialog = inject(MatDialog);
  private readonly qualificationService: QualificationService = inject(QualificationService);

  ngOnInit() {
    this.loadQualifications();
  }

  private loadQualifications() {
    this.qualifications$ = this.qualificationService.getAll();
  }

  openCreateModal() {
    const dialogRef = this.dialog.open(CreateComponent);

    dialogRef.afterClosed().subscribe(result => {
      if (result) {
        this.loadQualifications();
      }
    });
  }

  openEditModal(qualification: Qualification) {
    const dialogRef = this.dialog.open(EditComponent, {
      data: qualification
    });

    dialogRef.afterClosed().subscribe(result => {
      if (result) {
        this.loadQualifications();
      }
    });
  }
}
